@@ -3,19 +3,25 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name' : 'Party',
+    'name_bg_BG': 'Партньор',
     'name_de_DE': 'Parteien',
     'name_es_CO': 'Terceros',
     'name_es_ES': 'Terceros',
     'name_fr_FR': 'Tiers',
-    'version' : '1.8.0',
+    'name_nl_NL': 'Relaties',
+    'name_ru_RU': 'Контрагенты',
+    'version' : '2.0.0',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': 'Define parties, addresses and co.',
+    'description_bg_BG': 'Задаване на партньори, адреси и тн.',
     'description_de_DE': 'Ermöglicht die Erstellung von Parteien, Adressen, etc.',
     'description_es_CO': 'Definición de terceros, direcciones, etc.',
     'description_es_ES': 'Define terceros, direcciones, etc...',
     'description_fr_FR': 'Définit des tiers, des adresses, etc.',
+    'description_nl_NL': 'Definieert relaties, adressen en bedrijven.',
+    'description_ru_RU': 'Определение контрагентов, адресов и тп.',
     'depends' : [
         'ir',
         'res',
@@ -29,9 +35,12 @@
         'configuration.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'nl_NL.csv',
+        'ru_RU.csv',
     ],
 }
